@@ -1,4 +1,4 @@
-package EAI::Common 1.9;
+package EAI::Common 1.901;
 
 use strict; use feature 'unicode_strings'; use warnings; no warnings 'uninitialized';
 use Exporter qw(import); use EAI::DateUtil; use Data::Dumper qw(Dumper); use Getopt::Long qw(:config no_ignore_case); use Log::Log4perl qw(get_logger); use MIME::Lite (); use Scalar::Util qw(looks_like_number);
@@ -505,6 +505,9 @@ sub setupLogging {
 	Log::Log4perl::init($logConfig);
 	my $logger = get_logger();
 	$logger->warn($noLogFolderErr) if $noLogFolderErr;
+	if (Log::Log4perl->appenders()->{"FILE"} and Log::Log4perl->appenders()->{"FILE"}->{"appender"}->{"fh"}) {
+		Log::Log4perl->appenders()->{"FILE"}->{"appender"}->{"fh"}->autoflush;
+	}
 	if ($config{smtpServer}) {
 		# remove explicitly enumerated lookups (1:scriptname.pl, 2:scriptname.pl)
 		for my $lookupKey (keys(%{$config{checkLookup}})) {
